| make_msv | R Documentation |
Make the text string for a multivariate stochastic volatility model using arrow-lag-slope notation for DSEM.
make_msv(
variables,
n_factors,
factor_names = paste0("F", seq_len(n_factors)),
collapse_text = TRUE
)
variables |
Character string of variables (i.e., column names of |
n_factors |
Number of stochastic volatility factors. |
factor_names |
Optional character-vector of factor names,
which must match NA columns in |
collapse_text |
whether to collapse text into long character string |
A text string to be passed to dsem
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.