Make the text string for a multivariate stochastic volatility model using arrow-lag-slope notation for DSEM.
Value
A text string to be passed to dsem
Make the text string for a multivariate stochastic volatility model using arrow-lag-slope notation for DSEM.
A text string to be passed to dsem