Learn R Programming

dsem (version 1.3.0)

plot.dsem: Simulate dsem

Description

Plot from a fitted dsem model

Usage

# S3 method for dsem
plot(x, y, edge_label = c("name", "value"), digits = 2, ...)

Value

Invisibly returns the output from graph_from_data_frame

which was passed to plot.igraph for plotting.

Arguments

x

Output from dsem

y

Not used

edge_label

Whether to plot parameter names or estimated values

digits

integer indicating the number of decimal places to be used

...

arguments passed to plot.igraph

Details

This function coerces output from a graph and then plots the graph.