Plot from a fitted dsem model
# S3 method for dsem
plot(x, y, edge_label = c("name", "value"), digits = 2, ...)Invisibly returns the output from graph_from_data_frame
which was passed to plot.igraph for plotting.
Output from dsem
Not used
Whether to plot parameter names or estimated values
integer indicating the number of decimal places to be used
arguments passed to plot.igraph
This function coerces output from a graph and then plots the graph.